Sign inSign up

arfshl/instagram-viewer-py

By arfshl

Updated about 1 month ago

Easy-mode Instaloader wrapper

Image
Developer tools
Data science
0

378

arfshl/instagram-viewer-py repository overview

instagram-viewer-py

Easy-mode Instaloader wrapper

GitHub

Installation
git clone https://github.com/arfshl/instagram-viewer-py.git
cd instagram-viewer-py
pip install --no-cache-dir -r requirements.
Docker
docker pull arfshl/instagram-viewer-py:latest

Easy Usage
Fetch recent posts from a profile:
python instagram-viewer.py --username <username> --post 5
docker run --rm -it -v "$PWD:/work" arfshl/instagram-viewer-py --username <username> --post 5
Fetch active stories anonymously (Requires Login):
python instagram-viewer.py --username <username> --stories --login --anon-story
docker run --rm -it -v "$PWD:/work" arfshl/instagram-viewer-py --username <username> --stories --login --anon-story
View followers or following list (Requires Login):
python instagram-viewer.py --username <username> --followers --post 20 --login
Delete local session (Logout):
python instagram-viewer.py --logout my_account

Command-line options
Options:
   --help               Show this help message and exit
   --username           Target username
   --post               Limit count (default: 10)
   --tagged             Fetch tagged posts
   --login              Prompt for login credentials
   --logout             Remove saved session file by username
   --highlights         List highlights
   --highlight-view     View specific highlight by Name or ID
   --stories            Fetch stories
   --anon-story         View stories anonymously
   --followers          List followers
   --following          List following

Disclaimer: This project or Instaloader is in no way affiliated with, authorized, maintained or endorsed by Instagram or any of its affiliates or subsidiaries. This is an independent and unofficial project. Use at your own risk.

Tag summary

Content type

Image

Digest

sha256:e39ae28ec

Size

42.7 MB

Last updated

about 1 month ago

docker pull arfshl/instagram-viewer-py